[−][src]Struct ergo_lib::sigma_protocol::private_input::DlogProverInput
Secret key of discrete logarithm signature protocol
Fields
w: Scalarsecret key value
Implementations
impl DlogProverInput[src]
pub const SIZE_BYTES: usize[src]
Scalar(secret key) size in bytes
pub fn random() -> DlogProverInput[src]
generates random secret in the range [0, n), where n is DLog group order.
pub fn from_bytes(bytes: &[u8; 32]) -> Option<DlogProverInput>[src]
Attempts to parse the given byte array as an SEC-1-encoded scalar(secret key). Returns None if the byte array does not contain a big-endian integer in the range [0, modulus).
pub fn to_bytes(&self) -> [u8; 32][src]
byte representation of the underlying scalar
pub fn public_image(&self) -> ProveDlog[src]
public key of discrete logarithm signature protocol